===========================================================
 passagemath: Embeddable Common Lisp
===========================================================

About SageMath
--------------

   "Creating a Viable Open Source Alternative to
    Magma, Maple, Mathematica, and MATLAB"

   Copyright (C) 2005-2024 The Sage Development Team

   https://www.sagemath.org

SageMath fully supports all major Linux distributions, recent versions of
macOS, and Windows (Windows Subsystem for Linux).

See https://doc.sagemath.org/html/en/installation/index.html
for general installation instructions.


About this pip-installable distribution package
-----------------------------------------------

This pip-installable distribution ``passagemath-ecl`` is a distribution of a part of the Sage Library.
It ships the Cython interface to Embeddable Common Lisp.


What is included
----------------

* Binary wheels on PyPI contain a prebuilt copy of
  `Embeddable Common Lisp <https://doc.sagemath.org/html/en/reference/spkg/ecl.html>`_
